@@ -34,27 +34,26 @@ import sys
 from PyQt4 import QtGui, QtCore
 
 # Module used to include the resources into this file
-# Unused import resources_rc, pylint: disable=W0611
 from ubuntu_sso.qt.ui import resources_rc
-# pylint: enable=W0611
 from ubuntu_sso.qt.ubuntu_sso_wizard import UbuntuSSOClientGUI
 from ubuntu_sso.utils import compat, PLATFORM_QSS
 
 
-# Invalid name "source", pylint: disable=C0103
+# Poke resources_rc to avoid pyflakes complaining about unused import
+assert(resources_rc)
+
 if sys.platform in ('win32', 'darwin'):
     from ubuntu_sso.qt.main import windows
     source = windows
 else:
     from ubuntu_sso.qt.main import linux
     source = linux
-# pylint: enable=C0103
 
 
 def main(**kwargs):
     """Start the QT mainloop and open the main window."""
     if os.environ.get('TESTABILITY', False) and \
-        '-testability' not in sys.argv:
+            '-testability' not in sys.argv:
         sys.argv.append('-testability')
     app = QtGui.QApplication(sys.argv)
 
@@ -72,7 +71,6 @@ def main(**kwargs):
         if isinstance(value, compat.binary_type):
             kwargs[key] = value.decode('utf-8')
 
-    # Unused variable 'ui', pylint: disable=W0612
     close_callback = lambda: source.main_quit(app)
     ui = UbuntuSSOClientGUI(close_callback=close_callback, **kwargs)
     style = QtGui.QStyle.alignedRect(
