@@ -43,6 +43,7 @@ except ImportError:
     from urlparse import urlparse, urljoin, parse_qsl
 
 from OpenSSL import crypto
+from oauth import oauth
 from socket import gethostname
 from twisted.cred import checkers, portal
 from twisted.internet import defer
@@ -65,7 +66,13 @@ from ubuntu_sso import (
 from ubuntu_sso.utils import webclient
 from ubuntu_sso.utils.ui import SSL_DETAILS_TEMPLATE
 from ubuntu_sso.utils.webclient import gsettings, txweb
-from ubuntu_sso.utils.webclient.common import BaseWebClient, HeaderDict, oauth
+from ubuntu_sso.utils.webclient.common import (
+    BaseWebClient,
+    HeaderDict,
+
+    UnauthorizedError,
+    WebClientError,
+)
 
 ANY_VALUE = object()
 SAMPLE_KEY = "result"
@@ -203,8 +210,8 @@ def get_root_resource():
 
     root.putChild(THROWERROR, resource.NoResource())
 
-    unauthorized_resource = resource.ErrorPage(resource.http.UNAUTHORIZED,
-                                                "Unauthorized", "Unauthorized")
+    unauthorized_resource = resource.ErrorPage(http.UNAUTHORIZED,
+                                               "Unauthorized", "Unauthorized")
     root.putChild(UNAUTHORIZED, unauthorized_resource)
     root.putChild(HEADONLY, HeadOnlyResource())
     root.putChild(VERIFYHEADERS, VerifyHeadersResource())
@@ -239,15 +246,6 @@ class HTTPSMockWebServer(HTTPSWebServer):
         super(HTTPSMockWebServer, self).__init__(root, ssl_settings)
 
 
-class FakeQApplication(object):
-    """A fake Qt module."""
-
-    @classmethod
-    def instance(cls):
-        """Return the instance."""
-        return cls
-
-
 class ModuleSelectionTestCase(TestCase):
     """Test the functions to choose the qtnet or libsoup backend."""
 
@@ -258,9 +256,6 @@ class ModuleSelectionTestCase(TestCase):
 
     def test_is_qt4reactor_installed_installed_core(self):
         """When the qt4reactor is installed, it returns true."""
-        from PyQt4 import QtCore
-
-        self.patch(QtCore, 'QCoreApplication', FakeQApplication)
         self.assertTrue(webclient.is_qt4reactor_installed())
 
     def assert_module_name(self, module, expected_name):
@@ -314,7 +309,7 @@ class WebClientTestCase(TestCase):
     def test_get_iri_error(self):
         """The errback is called when there's some error."""
         yield self.assertFailure(self.wc.request(self.base_iri + THROWERROR),
-                                 webclient.WebClientError)
+                                 WebClientError)
 
     @defer.inlineCallbacks
     def test_zero_byte_in_content(self):
@@ -345,7 +340,7 @@ class WebClientTestCase(TestCase):
     def test_unauthorized(self):
         """Detect when a request failed with the UNAUTHORIZED http code."""
         yield self.assertFailure(self.wc.request(self.base_iri + UNAUTHORIZED),
-                                 webclient.UnauthorizedError)
+                                 UnauthorizedError)
 
     @defer.inlineCallbacks
     def test_method_head(self):
@@ -377,7 +372,7 @@ class WebClientTestCase(TestCase):
                                           password="wrong password!")
         self.addCleanup(other_wc.shutdown)
         yield self.assertFailure(other_wc.request(self.base_iri + GUARDED),
-                                 webclient.UnauthorizedError)
+                                 UnauthorizedError)
 
     @defer.inlineCallbacks
     def test_request_is_oauth_signed(self):
@@ -418,7 +413,7 @@ class WebClientTestCase(TestCase):
     def test_webclienterror_not_string(self):
         """The returned exception contains unicode data."""
         deferred = self.wc.request(self.base_iri + THROWERROR)
-        failure = yield self.assertFailure(deferred, webclient.WebClientError)
+        failure = yield self.assertFailure(deferred, WebClientError)
         for error in failure.args:
             self.assertTrue(isinstance(error, basestring))
 
@@ -508,6 +503,7 @@ class TxWebClientReactorReplaceableTestCase(TestCase):
         fake_reactor = FakeSavingReactor()
         wc = txweb.WebClient(fake_reactor)
         _response = yield wc.request(iri)
+        assert(_response)
         host, _port, _args = fake_reactor.connections[0]
         self.assertEqual(host, self.FAKE_HOST)
 
@@ -681,7 +677,7 @@ class BasicProxyTestCase(SquidTestCase):
 
         self.wc.force_use_proxy(partial_settings)
         self.failUnlessFailure(self.wc.request(self.base_iri + SIMPLERESOURCE),
-                               webclient.WebClientError)
+                               WebClientError)
 
     if WEBCLIENT_MODULE_NAME.endswith(".txweb"):
         reason = "txweb does not support proxies."
@@ -905,14 +901,13 @@ class RequestProxyAuthTestCase(TestCase):
         """Test the case when we cannot spawn the process."""
         self.spawn_return_code = Exception()
         self.failUnlessFailure(self.wc.request_proxy_auth_credentials(
-                                         self.domain, True),
-                                         webclient.WebClientError)
+                self.domain, True), WebClientError)
 
     @defer.inlineCallbacks
     def test_creds_acquired(self):
         """Test the case in which we do get the creds."""
-        got_creds = yield self.wc.request_proxy_auth_credentials(self.domain,
-                                                           self.retry)
+        got_creds = yield self.wc.request_proxy_auth_credentials(
+            self.domain, self.retry)
         self.assertTrue(got_creds, 'Return true when creds are present.')
         self.assertEqual(self.wc.proxy_username, self.creds['username'])
         self.assertEqual(self.wc.proxy_password, self.creds['password'])
@@ -921,8 +916,7 @@ class RequestProxyAuthTestCase(TestCase):
         """Test the case in which we cannot access the keyring."""
         self.keyring.creds = Exception()
         self.failUnlessFailure(self.wc.request_proxy_auth_credentials(
-                                         self.domain, self.retry),
-                                         webclient.WebClientError)
+                self.domain, self.retry), WebClientError)
 
     @defer.inlineCallbacks
     def test_creds_none(self):
@@ -962,8 +956,8 @@ class BaseSSLTestCase(SquidTestCase):
                                  country_name='UK',
                                  state_name='London',)
         self.ssl_settings = self._generate_self_signed_certificate(
-                                                             self.cert_dir,
-                                                             self.cert_details)
+            self.cert_dir,
+            self.cert_details)
         self.addCleanup(self._clean_ssl_certificate_files)
 
         self.ws = HTTPSMockWebServer(self.ssl_settings)
@@ -1071,7 +1065,7 @@ class CorrectProxyTestCase(BaseSSLTestCase):
         # we fail due to the fake ssl cert
         yield self.failUnlessFailure(self.wc.request(
                                      self.base_iri + SIMPLERESOURCE),
-                                     webclient.WebClientError)
+                                     WebClientError)
         # https requests do not use the auth proxy therefore called should be
         # empty. This asserts that we are using the correct settings for the
         # request.
@@ -1159,8 +1153,7 @@ class SSLTestCase(BaseSSLTestCase):
     def test_ssl_fail(self):
         """Test showing the dialog and rejecting."""
         self.failUnlessFailure(self.wc.request(
-                                     self.base_iri + SIMPLERESOURCE),
-                                     webclient.WebClientError)
+                self.base_iri + SIMPLERESOURCE), WebClientError)
         self.assertNotEqual(None, self.memento.check_error('SSL errors'))
 
     def test_format_ssl_details(self):
